@@ -1,11 +1,12 @@
 from crawlab.db import col
-from crawlab.utils import get_task_id
+from crawlab.utils import save_item_mongo
+from crawlab.utils.config import get_task_id
 
 
 class CrawlabMongoPipeline(object):
     def process_item(self, item, spider):
         item_dict = dict(item)
         item_dict['task_id'] = get_task_id()
-        col.save(item_dict)
+        save_item_mongo(item_dict)
 
         return item
